import { Component, OnInit, Output, EventEmitter, Input, ContentChild, ElementRef, OnChanges, DoCheck, SimpleChanges, AfterContentInit, AfterContentChecked, AfterViewInit, AfterViewChecked } from '@angular/core';
import { User } from '../models/user.model';
import { UsersService } from '../services/users.service';
import { NgModel, NgForm, FormGroup, FormControl, Validators } from '@angular/forms';

@Component({
  selector: 'app-user-form',
  templateUrl: './user-form.component.html',
  styleUrls: ['./user-form.component.sass'],
  styles: [
    `
    input.ng-touched.ng-invalid {border: solid red 3px}
    input.ng-touched.ng-valid {border: solid green 3px}
    `
  ]
})
export class UserFormComponent implements OnChanges, OnInit, DoCheck, AfterContentInit, AfterContentChecked, AfterViewInit, AfterViewChecked {


  @Output() onUserAdded: EventEmitter<User> = new EventEmitter<User>(); 
  @Output() nameChange:EventEmitter<string> = new EventEmitter<string>();

  @Input() name: string;

  age:number = 45;

  user: User;

  isWarning: boolean = true;

  title: string = "Форма добавления пользователя";

  @ContentChild('fromParent')
  fromParent: ElementRef;

  userForm: FormGroup = new FormGroup({
    "name" : new FormControl("John",[
        Validators.required,
        Validators.maxLength(10),
        Validators.minLength(3)
    ]),
    "age" : new FormControl("",[
        Validators.required
    ]),
  });


  ngOnChanges(changes: SimpleChanges) {
    console.log('ngOnChanges');
    console.log(changes);

  }

  ngOnInit() {
    console.log('ngOnInit');
  }

  ngDoCheck() {
    console.log('ngDoCheck');
  }

  ngAfterContentInit() {
    console.log('ngAfterContentInit');
  }

  ngAfterContentChecked() {
    console.log('ngAfterContentChecked');
  }

  ngAfterViewInit() {
    console.log('ngAfterViewInit');
  }

  ngAfterViewChecked() {
    console.log('ngAfterViewChecked');
  }





  constructor() { 
    this.user =  new User('John',15);
  }


  save(event, name: NgModel, age: NgModel) {
    

    let userTmp: User = new User(name.value, age.value);
    this.onUserAdded.emit(userTmp);

    this.fromParent.nativeElement.textContent = "Hello Parent";
    
  }

  onChange(event) {
    this.name = event.target.value;
    //console.log(event.target.value);
  }

  onNameUserChange($event : string) {
      this.name = $event;
      this.nameChange.emit($event);
  }

  onUserNameChange($event) : void {
    if(this.user.name.length < 3) {
      this.user.name = "Имя пользователя должно быть больше 3х символов";
    }
    else {
      this.user.name = $event;
    }
  }

  onSubmit() {
    //console.log(form.controls['age'].value);
  }

}
